@@ -6,39 +6,45 @@ from typing import Any, Iterator, List, Optional
 
 from .lap import Lap
 from .statistics import Statistics
-from .utils import format_elapsed_time, Caller, inspect_caller
+from .utils import Caller, format_elapsed_time, inspect_caller
 
 
 class Stopwatch:
     name: Optional[str] = None
+    precision: int = 2
     _caller: Optional[Caller] = None
     _laps: List[Lap] = []
     _current_lap: Optional[Lap] = None
     _print_report: bool = False
 
-    def __init__(self,
-                 name: Optional[str] = None,
-                 print_report: bool = False) -> None:
+    def __init__(
+        self,
+        name: Optional[str] = None,
+        print_report: bool = False,
+        precision: int = 2
+    ) -> None:
         self.name = name
+        self.precision = precision
         if print_report:
-            self.print_report = print_report
+            self._print_report = print_report
             self._caller = inspect_caller()
         self.restart()
 
     def __enter__(self) -> Stopwatch:
         return self.restart()
 
-    def __exit__(self, exc_type: Any, exc_value: Any,
-                 exc_traceback: Any) -> None:
+    def __exit__(
+        self, exc_type: Any, exc_value: Any, exc_traceback: Any
+    ) -> None:
         self.stop()
-        if self.print_report:
+        if self._print_report:
             print(self._format())
 
     def __str__(self) -> str:
-        return format_elapsed_time(self.elapsed)
+        return format_elapsed_time(self.elapsed, self.precision)
 
     def __repr__(self) -> str:
-        return f'Stopwatch(name={self.name}, elapsed={self.elapsed})'
+        return f'<Stopwatch name={self.name} elapsed={self.elapsed}>'
 
     @property
     def laps(self) -> List[float]:
@@ -129,28 +135,31 @@ class Stopwatch:
         """
         statistics = Statistics(values=self.laps)
 
-        items = [f'total={statistics.total:.4f}s']
+        items = [f'total={statistics.total:.{self.precision}f}s']
         if len(statistics) > 1:
-            items.extend([
-                f'mean={statistics.mean:.4f}s',
-                f'min={statistics.minimum:.4f}s',
-                f'median={statistics.median:.4f}s',
-                f'max={statistics.maximum:.4f}s',
-                f'dev={math.sqrt(statistics.variance):.4f}s'
-            ])
+            items.extend(
+                [
+                    f'mean={statistics.mean:.{self.precision}f}s',
+                    f'min={statistics.minimum:.{self.precision}f}s',
+                    f'median={statistics.median:.{self.precision}f}s',
+                    f'max={statistics.maximum:.{self.precision}f}s',
+                    f'dev={math.sqrt(statistics.variance):.{self.precision}f}s'
+                ]
+            )
 
         return '[Stopwatch{tag}] {statistics}'.format(
             tag=f'#{self.name}' if self.name is not None else '',
-            statistics=', '.join(items))
+            statistics=', '.join(items)
+        )
 
     def _format(self) -> str:
         caller = self._caller
         # TODO : back with the colored print using colorama
-        if self.print_report and caller is not None:
+        if self._print_report and caller is not None:
             items = [
                 f'[{caller.module}:{caller.function}:{caller.line_number}]',
                 ' ~ ',
-                format_elapsed_time(self.elapsed)
+                format_elapsed_time(self.elapsed, self.precision)
             ]
 
             if self.name is not None:
